==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DiskFillSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiskFillSpecFluentImpl<A extends DiskFillSpecFluent<A>> extends BaseFluent<A> implements DiskFillSpecFluent<A>{
  public DiskFillSpecFluentImpl() {
  }
  public DiskFillSpecFluentImpl(DiskFillSpec instance) {
    this.withFillByFallocate(instance.getFillByFallocate()); 
    this.withPath(instance.getPath()); 
    this.withSize(instance.getSize()); 
  }
  private Boolean fillByFallocate;
  private String path;
  private String size;
  public Boolean getFillByFallocate() {
    return this.fillByFallocate;
  }
  public A withFillByFallocate(Boolean fillByFallocate) {
    this.fillByFallocate=fillByFallocate; return (A) this;
  }
  public Boolean hasFillByFallocate() {
    return this.fillByFallocate != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getSize() {
    return this.size;
  }
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  public Boolean hasSize() {
    return this.size != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DiskFillSpecFluentImpl that = (DiskFillSpecFluentImpl) o;
    if (fillByFallocate != null ? !fillByFallocate.equals(that.fillByFallocate) :that.fillByFallocate != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (size != null ? !size.equals(that.size) :that.size != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fillByFallocate,  path,  size,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fillByFallocate != null) { sb.append("fillByFallocate:"); sb.append(fillByFallocate + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  public A withFillByFallocate() {
    return withFillByFallocate(true);
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/DiskFillSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiskFillSpecFluentImpl<A extends DiskFillSpecFluent<A>> extends BaseFluent<A> implements DiskFillSpecFluent<A>{
  public DiskFillSpecFluentImpl() {
  }
  public DiskFillSpecFluentImpl(DiskFillSpec instance) {
    if (instance != null) {
      this.withFillByFallocate(instance.getFillByFallocate());
      this.withPath(instance.getPath());
      this.withSize(instance.getSize());
    }
  }
  private Boolean fillByFallocate;
  private String path;
  private String size;
  public Boolean getFillByFallocate() {
    return this.fillByFallocate;
  }
  public A withFillByFallocate(Boolean fillByFallocate) {
    this.fillByFallocate=fillByFallocate; return (A) this;
  }
  public Boolean hasFillByFallocate() {
    return this.fillByFallocate != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getSize() {
    return this.size;
  }
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  public Boolean hasSize() {
    return this.size != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskFillSpecFluentImpl that = (DiskFillSpecFluentImpl) o;
    if (!java.util.Objects.equals(fillByFallocate, that.fillByFallocate)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(size, that.size)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fillByFallocate,  path,  size,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fillByFallocate != null) { sb.append("fillByFallocate:"); sb.append(fillByFallocate + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  public A withFillByFallocate() {
    return withFillByFallocate(true);
  }
  
}
